@@ -7,11 +7,16 @@ __all__ = [
     "alist_batch_download_file_or_make_strm", 
 ]
 
+import logging
+
+from mimetypes import init
+init()
+from mimetypes import types_map
+
 from asyncio import run, to_thread, Semaphore, TaskGroup
 from collections.abc import Callable, Container, Iterable
 from concurrent.futures import ThreadPoolExecutor
 from contextlib import closing, aclosing
-from mimetypes import types_map, init
 from os import makedirs
 from os.path import dirname, exists, join as joinpath, normpath, splitext
 from json import dumps, loads
@@ -20,7 +25,9 @@ from alist import AlistClient, AlistPath
 from httpx import TimeoutException
 
 
-init()
+logging.basicConfig()
+logger = logging.getLogger("alist")
+logger.setLevel(logging.DEBUG)
 
 
 def alist_update_115_cookies(
@@ -36,7 +43,7 @@ def alist_update_115_cookies(
             if only_not_work and storage["status"] == "work":
                 continue
             addition = loads(storage["addition"])
-            addition["cookies"] = cookies
+            addition["cookie"] = cookies
             storage["addition"] = dumps(addition)
             client.admin_storage_update(storage)
 
@@ -117,7 +124,6 @@ def alist_batch_add_115_share_links(
 
 def alist_batch_download_file_or_make_strm(
     alist_client: None | AlistClient = None, 
-    alist_token: str = "", 
     alist_base_dir: str = "/", 
     output_dir: str = "", 
     strm_file_predicate: Container[str] | Callable[[AlistPath], bool] = {
@@ -125,24 +131,23 @@ def alist_batch_download_file_or_make_strm(
     }, 
     download_file_predicate: Container[str] | Callable[[AlistPath], bool] = (
         {k for k, v in types_map.items() if v.startswith(("image/", "text/"))} | # type: ignore
-        {".nfo", ".ass", ".idx", ".sbv", ".smi", ".srt", ".sub", ".ssa", ".vtt"}
+        {".nfo", ".ass", ".idx", ".sbv", ".smi", ".srt", ".sub", ".ssa", ".txt", ".vtt"}
     ), 
     overwrite: bool = False, 
     max_workers: int = 5, 
-    logger = None, 
+    logger = logger, 
     async_: bool = False, 
 ):
     """批量导出 strm 和下载文件
 
     :param alist_client: alist 客户端对象，例如 AlistClient(origin="http://localhost:5244", username="admin", password="123456")
-    :param alist_token: Alist 签名 token，默认为空
     :param alist_base_dir: 需要同步的 Alist 的目录，默认为 "/"
     :param output_dir: 文件输出目录，默认为当前工作目录
     :param strm_file_predicate: 判断是否要下载为 strm，如果为 Callable，则调用以判断，如果为 Container，则用扩展名判断
     :param download_file_predicate: 判断是否要下载为 文件，如果为 Callable，则调用以判断，如果为 Container，则用扩展名判断
     :param overwrite: 本地路径存在同名文件时是否重新生成/下载该文件，默认为 False
     :param max_workers: 最大并发数
-    :param logger: 日志实例，用于输出信息
+    :param logger: 日志实例，用于输出信息，如果为 None，则不输出
     :param async_: 是否异步执行
     """
     if alist_client is None:
@@ -167,14 +172,14 @@ def alist_batch_download_file_or_make_strm(
         async def async_work(path: AlistPath):
             local_path = joinpath(output_dir, normpath(path.relative_to(alist_base_dir)))
             try:
-                if not (use_strm := strm_predicate(path)) or down_predicate(path):
+                if not ((use_strm := strm_predicate(path)) or down_predicate(path)):
                     return
                 if use_strm:
                     local_path = splitext(local_path)[0] + ".strm"
                 if exists(local_path) and not overwrite:
                     logger and logger.info(f"跳过文件：{local_path!r}")
                     return
-                url = path.get_url(token=alist_token)
+                url = path.get_url(ensure_ascii=False)
                 if dir_ := dirname(local_path):
                     await to_thread(makedirs, dir_, exist_ok=True)
                 if use_strm:
@@ -187,6 +192,9 @@ def alist_batch_download_file_or_make_strm(
                             aclosing(await alist_client.request(url, "GET", parse=None, async_=True)) as resp, 
                             async_open(local_path, mode="wb") as file, 
                         ):
+                            if resp.headers["Content-Type"] == "application/json; charset=utf-8":
+                                resp.read()
+                                raise OSError(resp.json())
                             write = file.write
                             async for chunk in resp.aiter_bytes(1 << 16):
                                 await write(chunk)
@@ -209,14 +217,14 @@ def alist_batch_download_file_or_make_strm(
         def work(path: AlistPath):
             local_path = joinpath(output_dir, normpath(path.relative_to(alist_base_dir)))
             try:
-                if not (use_strm := strm_predicate(path)) or down_predicate(path):
+                if not ((use_strm := strm_predicate(path)) or down_predicate(path)):
                     return
                 if use_strm:
                     local_path = splitext(local_path)[0] + ".strm"
                 if exists(local_path) and not overwrite:
                     logger and logger.info(f"跳过文件：{local_path!r}")
                     return
-                url = path.get_url(token=alist_token)
+                url = path.get_url(ensure_ascii=False)
                 if dir_ := dirname(local_path):
                     makedirs(dir_, exist_ok=True)
                 if use_strm:
@@ -227,6 +235,9 @@ def alist_batch_download_file_or_make_strm(
                         closing(alist_client.request(url, "GET", parse=None)) as resp, 
                         open(local_path, mode="wb") as file, 
                     ):
+                        if resp.headers["Content-Type"] == "application/json; charset=utf-8":
+                            resp.read()
+                            raise OSError(resp.json())
                         write = file.write
                         for chunk in resp.iter_bytes(1 << 16):
                             write(chunk)
@@ -234,12 +245,16 @@ def alist_batch_download_file_or_make_strm(
             except:
                 logger and logger.exception(f"下载失败: {local_path!r}")
                 raise
-        with ThreadPoolExecutor(max_workers=max_workers) as executor:
-            submit = executor.submit
-            for path in alist_client.fs.iter(
-                alist_base_dir, 
-                max_depth=-1, 
-                predicate=lambda path: path.is_file(), 
-            ):
-                submit(work, path)
+        executor = ThreadPoolExecutor(max_workers=max_workers)
+        try:
+            with executor:
+                submit = executor.submit
+                for path in alist_client.fs.iter(
+                    alist_base_dir, 
+                    max_depth=-1, 
+                    predicate=lambda path: path.is_file(), 
+                ):
+                    submit(work, path)
+        finally:
+            executor.shutdown(wait=False, cancel_futures=True)
 
